@@ -9,8 +9,6 @@ import pysam
 import subprocess
 import tempfile
 
-from multiprocessing import Pool
-
 from argparse import ArgumentParser
 
 
@@ -55,19 +53,6 @@ def parse_arguments():
     return parser.parse_args()
 
 
-def extract_records(input_bam, output_sam, condition='NR%4<2', processes=1):
-    pysam.view('-@', str(processes - 1), '-H', '-o', output_sam, input_bam)
-    with open(input_bam, 'r') as f0, open(output_sam, 'a') as f1:
-        with subprocess.Popen(
-            ('samtools', 'view'), stdin=f0, stdout=subprocess.PIPE
-        ) as view:
-            subprocess.Popen(
-                ('awk', f'{{if({condition}){{print}}}}'),
-                stdin=view.stdout,
-                stdout=f1
-            )
-
-
 def main():
     args = parse_arguments()
     with tempfile.TemporaryDirectory(dir=args.tmp_dir) as temp_dir:
@@ -82,13 +67,20 @@ def main():
             '-o', temp_in,
             args.input
         )
-        with Pool(processes=max(args.processes, 2)) as pool:
-            pool.starmap(
-                extract_records,
-                (
-                    (temp_in, temp_out0, 'NR%4<2', args.processes),
-                    (temp_in, temp_out1, 'NR%4>=2', args.processes)
-                )
+        for out in temp_out0, temp_out1:
+            pysam.view(
+                '-@', str(args.processes - 1),
+                '-H',
+                '-o', out,
+                temp_in
             )
+        with open(temp_in, 'r') as f:
+            with subprocess.Popen(
+                ('samtools', 'view'), stdin=f, stdout=subprocess.PIPE
+            ) as view:
+                subprocess.run(
+                    ('awk', f'{{if(NR%4<2){{print >> "{temp_out0}"}} else {{print >> "{temp_out1}"}}}}'),
+                    stdin=view.stdout
+                )
         for tmp_out, out in (temp_out0, args.out0), (temp_out1, args.out1):
             pysam.view('-@', str(args.processes - 1), '-bh', '-o', out, tmp_out)
